@@ -9,6 +9,8 @@ use Test::MockModule qw{strict};
 
 use Carp qw(croak);
 
+our $VERSION = '0.031';
+
 sub register {
     my ($self) = @_;
 
@@ -33,7 +35,7 @@ sub register {
 
             Test::MockFile::add_strict_rule_for_filename( $out[1] => 1 );
 
-            return @out;
+            return wantarray ? @out : $out[0];
         }
     );
 
